Installation
------------

Prerequisites
~~~~~~~~~~~~~~

Install python 3.7
Astir uses python 3.*


Astir installation
~~~~~~~~~~~~~~~~~~
PyPI
####

.. code::

    pip3 install astir


Dev
###
Clone this repo and run

.. code::

    git clone https://github.com/camlab-bioml/astir.git
    cd astir
    pip install -e .

